@@ -1045,5 +1045,23 @@ void l7vs::LoggerImpl::loadConf()
 	if (LOG_LV_INFO >= this->getLogLevel(loggerCategory)) {
 		this->putLogInfo(loggerCategory,2, "Logger Configuration Succeed.", __FILE__, __LINE__);
 	}
+	initLogLevelTable();
 }
 
+/*!
+ * initialize LogLevel table.
+ * initialize the LogLevel table.
+ *
+ * @param   void
+ * @return  void
+ */
+void l7vs::LoggerImpl::initLogLevelTable(void)
+{
+  int nCounter = 0;
+  
+  for (;nCounter < LOGGER_CATEGORY_NUM; nCounter++) {
+    loglevel[nCounter] = LOG_LV_NONE;
+  }
+
+  return;
+}
